/*	$NetBSD: msg_137.c,v 1.4 2022/06/22 19:23:18 rillig Exp $	*/
# 3 "msg_137.c"

// Test for message: use of incomplete enum type, op %s [137]
// This message is not used.

/* expect+1: warning: empty translation unit [272] */
