/*	$NetBSD: msg_040.c,v 1.4 2023/03/28 14:44:34 rillig Exp $	*/
# 3 "msg_040.c"

// Test for message: unknown size: %s [40]
/* This message is not used. */

/* lint1-flags: -Sw */

typedef int dummy;
