/* $NetBSD: lsym_else.c,v 1.3 2022/04/24 09:04:12 rillig Exp $ */

/*
 * Tests for the token lsym_else, which represents the keyword 'else' in an
 * 'if-else' statement.
 */

//indent input
// TODO: add input
//indent end

//indent run-equals-input
